@@ -12,7 +12,7 @@ import numpy as np
 import mne
 from mne.io.pick import channel_type
 from qtpy.QtCore import (Qt, Slot, QStringListModel, QModelIndex, QSettings,
-                         QEvent, QObject, QSize, QPoint)
+                         QEvent, QObject, QSize, QPoint, QMetaObject)
 from qtpy.QtGui import QKeySequence, QDropEvent, QIcon
 from qtpy.QtWidgets import (QApplication, QMainWindow, QFileDialog, QSplitter,
                             QMessageBox, QListView, QAction, QLabel, QFrame)
@@ -31,7 +31,7 @@ from .io.xdf import get_xml, get_streams
 from .viz import plot_erds
 
 
-__version__ = "0.6.1"
+__version__ = "0.6.3"
 
 MAX_RECENT = 6  # maximum number of recent files
 
@@ -132,7 +132,7 @@ class MainWindow(QMainWindow):
             self.actions[action] = self.export_menu.addAction(
                 f"{ext[1:].upper()} ({description[1]})...",
                 partial(self.export_file, model.export_data, "Export data",
-                        ext))
+                        "*" + ext))
         self.actions["export_bads"] = file_menu.addAction(
             "Export &bad channels...",
             lambda: self.export_file(model.export_bads, "Export bad channels",
@@ -444,10 +444,17 @@ class MainWindow(QMainWindow):
         """Export to file."""
         fname = QFileDialog.getSaveFileName(self, text, filter=ffilter)[0]
         if fname:
-            try:
-                f(fname, ffilter)
-            except TypeError:
-                f(fname)
+            if ffilter != "*":
+                exts = [ext.replace("*", "") for ext in ffilter.split()]
+
+                maxsuffixes = max([ext.count(".") for ext in exts])
+                suffixes = Path(fname).suffixes
+                for i in range(-maxsuffixes, 0):
+                    ext = "".join(suffixes[i:])
+                    if ext in exts:
+                        return f(fname)
+                fname = fname + exts[0]
+                return f(fname)
 
     def import_file(self, f, text, ffilter="*"):
         """Import file."""
@@ -686,15 +693,20 @@ class MainWindow(QMainWindow):
             self.model.history.append(history)
 
             pool = mp.Pool(processes=1)
+
+            def callback(x):
+                QMetaObject.invokeMethod(calc, "accept", Qt.QueuedConnection)
+
             res = pool.apply_async(func=ica.fit,
                                    args=(self.model.current["data"],),
                                    kwds={"reject_by_annotation":
                                          exclude_bad_segments},
-                                   callback=lambda x: calc.accept())
+                                   callback=callback)
             pool.close()
 
             if not calc.exec_():
                 pool.terminate()
+                print("ICA calculation aborted...")
             else:
                 self.model.current["ica"] = res.get(timeout=1)
                 self.model.history.append(f"ica.fit(inst=raw, "
@@ -840,7 +852,7 @@ class MainWindow(QMainWindow):
                 f'<nobr><p>MNE repository: '
                 f'<a href=https://{mne_url}>{mne_url}</a></p></nobr>'
                 f'<p>Licensed under the BSD 3-clause license.</p>'
-                f'<p>Copyright 2017-2020 by Clemens Brunner.</p>')
+                f'<p>Copyright 2017-2021 by Clemens Brunner.</p>')
         msg_box.setInformativeText(text)
         msg_box.exec_()
 
@@ -980,8 +992,7 @@ class MainWindow(QMainWindow):
         """
         write_settings(size=self.size(), pos=self.pos())
         if self.model.history:
-            print("\nCommand History")
-            print("===============")
+            print("\n# Command History\n")
             print("\n".join(self.model.history))
         QApplication.quit()
 
